searchData={"items":[{"type":"behaviour","title":"AgenthubSdk","doc":"Simple interface to make agents runnable on AgentHub.\n\nThis module provides the core behavior for creating agent runners that can be\nexecuted on the AgentHub platform.","ref":"AgenthubSdk.html"},{"type":"callback","title":"AgenthubSdk.run/1","doc":"Defines the behavior for an agent runner.\n\nAn agent runner must implement the `run/1` callback which takes input and\nreturns a result wrapped in a task or async operation.","ref":"AgenthubSdk.html#c:run/1"},{"type":"function","title":"AgenthubSdk.run/2","doc":"Runs an agent with the given input.\n\nThis function provides a standardized way to execute agents that implement\nthe AgentRunner behavior.","ref":"AgenthubSdk.html#run/2"},{"type":"function","title":"Parameters - AgenthubSdk.run/2","doc":"- `agent_module` - The module implementing the AgentRunner behavior\n- `input` - The input data to pass to the agent","ref":"AgenthubSdk.html#run/2-parameters"},{"type":"function","title":"Returns - AgenthubSdk.run/2","doc":"- `{:ok, result}` - On successful execution\n- `{:error, reason}` - On failure","ref":"AgenthubSdk.html#run/2-returns"},{"type":"function","title":"Examples - AgenthubSdk.run/2","doc":"iex> AgenthubSdk.run(MyAgent, %{data: \"test\"})\n    {:ok, %{result: \"processed\"}}","ref":"AgenthubSdk.html#run/2-examples"},{"type":"extras","title":"AgentHub SDK","doc":"# AgentHub SDK\n\nSimple interface to make agents runnable on AgentHub.","ref":"readme.html"},{"type":"extras","title":"Installation - AgentHub SDK","doc":"Add `agenthub_sdk` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:agenthub_sdk, \"~> 1.0.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - AgentHub SDK","doc":"The AgentHub SDK provides a simple behavior for creating agent runners that can be executed on the AgentHub platform.","ref":"readme.html#usage"},{"type":"extras","title":"Creating an Agent - AgentHub SDK","doc":"To create an agent, implement the `AgenthubSdk` behavior:\n\n```elixir\ndefmodule MyAgent do\n  @behaviour AgenthubSdk\n\n  def run(input) do\n    # Process the input and return a result\n    {:ok, %{result: \"processed\", input: input}}\n  end\nend\n```","ref":"readme.html#creating-an-agent"},{"type":"extras","title":"Running an Agent - AgentHub SDK","doc":"Use `AgenthubSdk.run/2` to execute your agent:\n\n```elixir\nresult = AgenthubSdk.run(MyAgent, %{data: \"test\"})\ncase result do\n  {:ok, output} -> IO.puts(\"Success: #{inspect(output)}\")\n  {:error, reason} -> IO.puts(\"Error: #{inspect(reason)}\")\nend\n```","ref":"readme.html#running-an-agent"},{"type":"extras","title":"API Reference - AgentHub SDK","doc":"### `AgenthubSdk.run/2`\n\nRuns an agent with the given input.\n\n**Parameters:**\n- `agent_module` - The module implementing the AgentRunner behavior\n- `input` - The input data to pass to the agent\n\n**Returns:**\n- `{:ok, result}` - On successful execution\n- `{:error, reason}` - On failure","ref":"readme.html#api-reference"},{"type":"extras","title":"Behavior Callback - AgentHub SDK","doc":"Your agent module must implement:\n\n```elixir\n@callback run(input :: any()) :: {:ok, any()} | {:error, any()}\n```","ref":"readme.html#behavior-callback"},{"type":"extras","title":"License - AgentHub SDK","doc":"ISC","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}